OPT MODULE
OPT PREPROCESS
OPT EXPORT

MODULE 'exec/libraries'
MODULE 'intuition/intuition' , 'intuition/screens' , 'intuition/classes'
MODULE 'graphics/text' , 'graphics/rastport'
MODULE 'utility/hooks'

->#define MUI_NOSHORTCUTS
#define MUI_OBSOLETE /* include obsolete identifiers */

/***************************************************************************
**
** MUI - MagicUserInterface
** (c) 1993 by Stefan Stuntz
**
** Main Header File
**
****************************************************************************
** Class Tree
****************************************************************************
**
** rootclass               (BOOPSI's base class)
** +--Notify               (implements notification mechanism)
**    +--Family            (handles multiple children)
**    !  +--Menustrip      (describes a complete menu strip)
**    !  +--Menu           (describes a single menu)
**    !  \--Menuitem       (describes a single menu item)
**    +--Application       (main class for all applications)
**    +--Window            (handles intuition window related topics)
**    +--Area              (base class for all GUI elements)
**       +--Rectangle      (creates (empty) rectangles)
**       +--Image          (creates images)
**       +--Text           (creates some text)
**       +--String         (creates a string gadget)
**       +--Prop           (creates a proportional gadget)
**       +--Gauge          (creates a fule gauge)
**       +--Scale          (creates a percentage scale)
**       +--Boopsi         (interface to BOOPSI gadgets)
**       +--Colorfield     (creates a field with changeable color)
**       +--List           (creates a line-oriented list)
**       !  +--Floattext   (special list with floating text)
**       !  +--Volumelist  (special list with volumes)
**       !  +--Scrmodelist (special list with screen modes)
**       !  \--Dirlist     (special list with files)
**       +--Group          (groups other GUI elements)
**          +--Register    (handles page groups with titles)
**          +--Virtgroup   (handles virtual groups)
**          +--Scrollgroup (handles virtual groups with scrollers)
**          +--Scrollbar   (creates a scrollbar)
**          +--Listview    (creates a listview)
**          +--Radio       (creates radio buttons)
**          +--Cycle       (creates cycle gadgets)
**          +--Slider      (creates slider gadgets)
**          +--Coloradjust (creates some RGB sliders)
**          +--Palette     (creates a complete palette gadget)
**          +--Colorpanel  (creates a panel of colors)
**          +--Popstring   (base class for popups)
**             +--Popobject(popup a MUI object in a window)
**             \--Popasl   (popup an asl requester)
**
****************************************************************************
** General Header File Information
****************************************************************************
**
** All macro and structure definitions follow these rules:
**
** Name                       Meaning
**
** MUIC_<class>               Name of a class
** MUIM_<class>_<method>      Method
** MUIP_<class>_<method>      Methods parameter structure
** MUIV_<class>_<method>_<x>  Special method value
** MUIA_<class>_<attrib>      Attribute
** MUIV_<class>_<attrib>_<x>  Special attribute value
** MUIE_<error>               Error return code from Mui_Error()
** MUII_<name>                Standard MUI image
** MUIX_<code>                Control codes for text strings
** MUIO_<name>                Object type for Mui_MakeObjectA()
**
** MUIA_... attribute definitions are followed by a comment
** consisting of the three possible letters I, S and G.
** I: it's possible to specify this attribute at object creation time.
** S: it's possible to change this attribute with SetAttrs().
** G: it's possible to get this attribute with GetAttr().
**
** Items marked with "Custom Class" are for use in custom classes only!
*/


/***************************************************************************
** Library specification
***************************************************************************/

#define MUIMASTER_NAME 'muimaster.library'
CONST MUIMASTER_VMIN = 10
CONST MUI_TRUE = 1 -> Added for Amiga E

/*
** !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
** Warning, the macros in this header file work only with muimaster.library
** V8 and above. If you recompile your programs, be sure to open
** muimaster.library with MUIMASTER_VMIN as version number.
** !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
*/



/***************************************************************************
** Object Types for Mui_MakeObjectA()
***************************************************************************/

CONST MUIO_Label       = 1    /* STRPTR label, ULONG flags */
CONST MUIO_Button      = 2    /* STRPTR label */
CONST MUIO_Checkmark   = 3    /* STRPTR label */
CONST MUIO_Cycle       = 4    /* STRPTR label, STRPTR *entries */
CONST MUIO_Radio       = 5    /* STRPTR label, STRPTR *entries */
CONST MUIO_Slider      = 6    /* STRPTR label, LONG min, LONG max */
CONST MUIO_String      = 7    /* STRPTR label, LONG maxlen */
CONST MUIO_PopButton   = 8    /* STRPTR imagespec */
CONST MUIO_HSpace      = 9    /* LONG space   */
CONST MUIO_VSpace      = 10   /* LONG space   */
CONST MUIO_HBar        = 11   /* LONG space   */
CONST MUIO_VBar        = 12   /* LONG space   */
CONST MUIO_MenustripNM = 13   /* struct NewMenu *nm, ULONG flags */
CONST MUIO_Menuitem    = 14   /* STRPTR label, STRPTR shortcut, ULONG flags, ULONG data  */
CONST MUIO_BarTitle    = 15   /* STRPTR label */

CONST MUIO_Label_SingleFrame = $100
CONST MUIO_Label_DoubleFrame = $200
CONST MUIO_Label_LeftAligned = $400
CONST MUIO_Label_Centered    = $800


/***************************************************************************
** ARexx Interface
***************************************************************************/

OBJECT mui_command
	mc_name        : PTR TO CHAR
	mc_template    : PTR TO CHAR
	mc_parameters  : LONG
	mc_hook        : PTR TO hook
	mc_reserved[5] : ARRAY OF LONG
ENDOBJECT

CONST MC_TEMPLATE_ID = -1

CONST MUI_RXERR_BADDEFINITION  = -1
CONST MUI_RXERR_OUTOFMEMORY    = -2
CONST MUI_RXERR_UNKNOWNCOMMAND = -3
CONST MUI_RXERR_BADSYNTAX      = -4


/***************************************************************************
** Return values for Mui_Error()
***************************************************************************/

CONST MUIE_OK                  = 0
CONST MUIE_OutOfMemory         = 1
CONST MUIE_OutOfGfxMemory      = 2
CONST MUIE_InvalidWindowObject = 3
CONST MUIE_MissingLibrary      = 4
CONST MUIE_NoARexx             = 5
CONST MUIE_SingleTask          = 6



/***************************************************************************
** Standard MUI Images
***************************************************************************/

CONST MUII_WindowBack     = 0   /* These images are configured   */
CONST MUII_RequesterBack  = 1   /* with the preferences program. */
CONST MUII_ButtonBack     = 2
CONST MUII_ListBack       = 3
CONST MUII_TextBack       = 4
CONST MUII_PropBack       = 5
CONST MUII_PopupBack      = 6
CONST MUII_SelectedBack   = 7
CONST MUII_ListCursor     = 8
CONST MUII_ListSelect     = 9
CONST MUII_ListSelCur     = 10
CONST MUII_ArrowUp        = 11
CONST MUII_ArrowDown      = 12
CONST MUII_ArrowLeft      = 13
CONST MUII_ArrowRight     = 14
CONST MUII_CheckMark      = 15
CONST MUII_RadioButton    = 16
CONST MUII_Cycle          = 17
CONST MUII_PopUp          = 18
CONST MUII_PopFile        = 19
CONST MUII_PopDrawer      = 20
CONST MUII_PropKnob       = 21
CONST MUII_Drawer         = 22
CONST MUII_HardDisk       = 23
CONST MUII_Disk           = 24
CONST MUII_Chip           = 25
CONST MUII_Volume         = 26
CONST MUII_PopUpBack      = 27
CONST MUII_Network        = 28
CONST MUII_Assign         = 29
CONST MUII_TapePlay       = 30
CONST MUII_TapePlayBack   = 31
CONST MUII_TapePause      = 32
CONST MUII_TapeStop       = 33
CONST MUII_TapeRecord     = 34
CONST MUII_GroupBack      = 35
CONST MUII_SliderBack     = 36
CONST MUII_SliderKnob     = 37
CONST MUII_TapeUp         = 38
CONST MUII_TapeDown       = 39
CONST MUII_Count          = 40

CONST MUII_BACKGROUND    = 128    /* These are direct color    */
CONST MUII_SHADOW        = 129    /* combinations and are not  */
CONST MUII_SHINE         = 130    /* affected by users prefs.  */
CONST MUII_FILL          = 131
CONST MUII_SHADOWBACK    = 132    /* Generally, you should     */
CONST MUII_SHADOWFILL    = 133    /* avoid using them. Better  */
CONST MUII_SHADOWSHINE   = 134    /* use one of the customized */
CONST MUII_FILLBACK      = 135    /* images above.             */
CONST MUII_FILLSHINE     = 136
CONST MUII_SHINEBACK     = 137
CONST MUII_FILLBACK2     = 138
CONST MUII_HSHINEBACK    = 139
CONST MUII_HSHADOWBACK   = 140
CONST MUII_HSHINESHINE   = 141
CONST MUII_HSHADOWSHADOW = 142
CONST MUII_LASTPAT       = 142
/*CONST MUII_N1HSHINE      = 143*/



/***************************************************************************
** Special values for some methods
***************************************************************************/

CONST MUIV_TriggerValue    = $49893131
CONST MUIV_NotTriggerValue = $49893133
CONST MUIV_EveryTime       = $49893131

CONST MUIV_Notify_Self        = 1
CONST MUIV_Notify_Window      = 2
CONST MUIV_Notify_Application = 3

CONST MUIV_Application_Save_ENV      = NIL
CONST MUIV_Application_Save_ENVARC   = $FFFFFFFF
CONST MUIV_Application_Load_ENV      = NIL
CONST MUIV_Application_Load_ENVARC   = $FFFFFFFF

CONST MUIV_Application_ReturnID_Quit = -1

CONST MUIV_List_Insert_Top           =  0
CONST MUIV_List_Insert_Active        = -1
CONST MUIV_List_Insert_Sorted        = -2
CONST MUIV_List_Insert_Bottom        = -3

CONST MUIV_List_Remove_First         =  0
CONST MUIV_List_Remove_Active        = -1
CONST MUIV_List_Remove_Last          = -2
CONST MUIV_List_Remove_Selected      = -3

CONST MUIV_List_Select_Off           =  0
CONST MUIV_List_Select_On            =  1
CONST MUIV_List_Select_Toggle        =  2
CONST MUIV_List_Select_Ask           =  3

CONST MUIV_List_GetEntry_Active      = -1
CONST MUIV_List_Select_Active        = -1
CONST MUIV_List_Select_All           = -2

CONST MUIV_List_Redraw_Active        = -1
CONST MUIV_List_Redraw_All           = -2

CONST MUIV_List_Move_Top             =  0
CONST MUIV_List_Move_Active          = -1
CONST MUIV_List_Move_Bottom          = -2
CONST MUIV_List_Move_Next            = -3 /* only valid for second parameter */
CONST MUIV_List_Move_Previous        = -4 /* only valid for second parameter */

CONST MUIV_List_Exchange_Top         =  0
CONST MUIV_List_Exchange_Active      = -1
CONST MUIV_List_Exchange_Bottom      = -2
CONST MUIV_List_Exchange_Next        = -3 /* only valid for second parameter */
CONST MUIV_List_Exchange_Previous    = -4 /* only valid for second parameter */

CONST MUIV_List_Jump_Top             =  0
CONST MUIV_List_Jump_Active          = -1
CONST MUIV_List_Jump_Bottom          = -2

CONST MUIV_Colorpanel_GetColor_Active = -1
CONST MUIV_Colorpanel_SetColor_Active = -1

CONST MUIV_List_NextSelected_Start    = -1
CONST MUIV_List_NextSelected_End      = -1


/***************************************************************************
** Control codes for text strings
***************************************************************************/

#define MUIX_R  '\er'    /* right justified */
#define MUIX_C  '\ec'    /* centered        */
#define MUIX_L  '\el'    /* left justified  */

#define MUIX_N  '\en'    /* normal     */
#define MUIX_B  '\eb'    /* bold       */
#define MUIX_I  '\ei'    /* italic     */
#define MUIX_U  '\eu'    /* underlined */

#define MUIX_PT  '\e2'   /* text pen           */
#define MUIX_PH  '\e8'   /* highlight text pen */



/***************************************************************************
** Parameter structures for some classes
***************************************************************************/

OBJECT mui_palette_entry
	mpe_id    : LONG
	mpe_red   : LONG
	mpe_green : LONG
	mpe_blue  : LONG
	mpe_group : LONG
ENDOBJECT

CONST MUIV_Palette_Entry_End = -1


OBJECT mui_scrmodelist_entry
	sme_name   : PTR TO CHAR
	sme_modeid : LONG
ENDOBJECT



/***************************************************************************
**
** Macro Section
** -------------
**
** To make GUI creation more easy and understandable, you can use the
** macros below. If you dont want, just define MUI_NOSHORTCUTS to disable
** them.
**
** These macros are available to C ...heu... E programmers only :-).
**
***************************************************************************/

#ifndef MUI_NOSHORTCUTS



/***************************************************************************
**
** Object Generation
** -----------------
**
** The xxxObject (and xChilds) macros generate new instances of MUI classes.
** Every xxxObject can be followed by tagitems specifying initial create
** time attributes for the new object and must be terminated with the
** End macro:
**
** obj = StringObject,
**          MUIA_String_Contents, 'foo',
**          MUIA_String_MaxLen  , 40,
**          End;
**
** With the Child, SubWindow and WindowContents shortcuts you can
** construct a complete GUI within one command:
**
** app = ApplicationObject,
**
**          ...
**
**          SubWindow, WindowObject,
**             WindowContents, VGroup,
**                Child, String('foo',40),
**                Child, String('bar',50),
**                Child, HGroup,
**                   Child, CheckMark(MUI_TRUE),
**                   Child, CheckMark(FALSE),
**                   End,
**                End,
**             End,
**
**          SubWindow, WindowObject,
**             WindowContents, HGroup,
**                Child, ...,
**                Child, ...,
**                End,
**             End,
**
**          ...
**
**          End;
**
***************************************************************************/

#define MenustripObject   Mui_NewObjectA(MUIC_Menustrip,[TAG_IGNORE,0
#define MenuObject        Mui_NewObjectA(MUIC_Menu,[TAG_IGNORE,0
#define MenuObjectT(name) Mui_NewObjectA(MUIC_Menu,[MUIA_Menu_Title,name
#define MenuitemObject    Mui_NewObjectA(MUIC_Menuitem,[TAG_IGNORE,0
#define WindowObject      Mui_NewObjectA(MUIC_Window,[TAG_IGNORE,0
#define ImageObject       Mui_NewObjectA(MUIC_Image,[TAG_IGNORE,0
#define BitmapObject      Mui_NewObjectA(MUIC_Bitmap,[TAG_IGNORE,0
#define BodychunkObject   Mui_NewObjectA(MUIC_Bodychunk,[TAG_IGNORE,0
#define NotifyObject      Mui_NewObjectA(MUIC_Notify,[TAG_IGNORE,0
#define ApplicationObject Mui_NewObjectA(MUIC_Application,[TAG_IGNORE,0
#define TextObject        Mui_NewObjectA(MUIC_Text,[TAG_IGNORE,0
#define RectangleObject   Mui_NewObjectA(MUIC_Rectangle,[TAG_IGNORE,0
#define ListObject        Mui_NewObjectA(MUIC_List,[TAG_IGNORE,0
#define PropObject        Mui_NewObjectA(MUIC_Prop,[TAG_IGNORE,0
#define StringObject      Mui_NewObjectA(MUIC_String,[TAG_IGNORE,0
#define ScrollbarObject   Mui_NewObjectA(MUIC_Scrollbar,[TAG_IGNORE,0
#define ListviewObject    Mui_NewObjectA(MUIC_Listview,[TAG_IGNORE,0
#define RadioObject       Mui_NewObjectA(MUIC_Radio,[TAG_IGNORE,0
#define VolumelistObject  Mui_NewObjectA(MUIC_Volumelist,[TAG_IGNORE,0
#define FloattextObject   Mui_NewObjectA(MUIC_Floattext,[TAG_IGNORE,0
#define DirlistObject     Mui_NewObjectA(MUIC_Dirlist,[TAG_IGNORE,0
#define SliderObject      Mui_NewObjectA(MUIC_Slider,[TAG_IGNORE,0
#define CycleObject       Mui_NewObjectA(MUIC_Cycle,[TAG_IGNORE,0
#define GaugeObject       Mui_NewObjectA(MUIC_Gauge,[TAG_IGNORE,0
#define ScaleObject       Mui_NewObjectA(MUIC_Scale,[TAG_IGNORE,0
#define BoopsiObject      Mui_NewObjectA(MUIC_Boopsi,[TAG_IGNORE,0
#define ColorfieldObject  Mui_NewObjectA(MUIC_Colorfield,[TAG_IGNORE,0
#define ColorpanelObject  Mui_NewObjectA(MUIC_Colorpanel,[TAG_IGNORE,0
#define ColoradjustObject Mui_NewObjectA(MUIC_Coloradjust,[TAG_IGNORE,0
#define PaletteObject     Mui_NewObjectA(MUIC_Palette,[TAG_IGNORE,0
#define GroupObject       Mui_NewObjectA(MUIC_Group,[TAG_IGNORE,0
#define RegisterObject    Mui_NewObjectA(MUIC_Register,[TAG_IGNORE,0
#define VirtgroupObject   Mui_NewObjectA(MUIC_Virtgroup,[TAG_IGNORE,0
#define ScrollgroupObject Mui_NewObjectA(MUIC_Scrollgroup,[TAG_IGNORE,0
#define PopstringObject   Mui_NewObjectA(MUIC_Popstring,[TAG_IGNORE,0
#define PopobjectObject   Mui_NewObjectA(MUIC_Popobject,[TAG_IGNORE,0
#define PoplistObject     Mui_NewObjectA(MUIC_Poplist,[TAG_IGNORE,0
#define PopaslObject      Mui_NewObjectA(MUIC_Popasl,[TAG_IGNORE,0
#define ScrmodelistObject Mui_NewObjectA(MUIC_Scrmodelist,[TAG_IGNORE,0
#define VGroup            Mui_NewObjectA(MUIC_Group,[TAG_IGNORE,0
#define HGroup            Mui_NewObjectA(MUIC_Group,[MUIA_Group_Horiz,MUI_TRUE
#define ColGroup(cols)    Mui_NewObjectA(MUIC_Group,[MUIA_Group_Columns,(cols)
#define RowGroup(rows)    Mui_NewObjectA(MUIC_Group,[MUIA_Group_Rows   ,(rows)
#define PageGroup         Mui_NewObjectA(MUIC_Group,[MUIA_Group_PageMode,MUI_TRUE
#define VGroupV           Mui_NewObjectA(MUIC_Virtgroup,[TAG_IGNORE,0
#define HGroupV           Mui_NewObjectA(MUIC_Virtgroup,[MUIA_Group_Horiz,MUI_TRUE
#define ColGroupV(cols)   Mui_NewObjectA(MUIC_Virtgroup,[MUIA_Group_Columns,(cols)
#define RowGroupV(rows)   Mui_NewObjectA(MUIC_Virtgroup,[MUIA_Group_Rows   ,(rows)
#define PageGroupV        Mui_NewObjectA(MUIC_Virtgroup,[MUIA_Group_PageMode,MUI_TRUE
#define RegisterGroup(t)  Mui_NewObjectA(MUIC_Register,[MUIA_Register_Titles,(t)
#define End               TAG_DONE])

#define Child             MUIA_Group_Child
#define SubWindow         MUIA_Application_Window
#define WindowContents    MUIA_Window_RootObject



/***************************************************************************
**
** Frame Types
** -----------
**
** These macros may be used to specify one of MUI's different frame types.
** Note that every macro consists of one { ti_Tag, ti_Data } pair.
**
** GroupFrameT() is a special kind of frame that contains a centered
** title text.
**
** HGroup, GroupFrameT('Horiz Groups'),
**    Child, RectangleObject, TextFrame  , End,
**    Child, RectangleObject, StringFrame, End,
**    Child, RectangleObject, ButtonFrame, End,
**    Child, RectangleObject, ListFrame  , End,
**    End,
**
***************************************************************************/

#define NoFrame          MUIA_Frame, MUIV_Frame_None
#define ButtonFrame      MUIA_Frame, MUIV_Frame_Button
#define ImageButtonFrame MUIA_Frame, MUIV_Frame_ImageButton
#define TextFrame        MUIA_Frame, MUIV_Frame_Text
#define StringFrame      MUIA_Frame, MUIV_Frame_String
#define ReadListFrame    MUIA_Frame, MUIV_Frame_ReadList
#define InputListFrame   MUIA_Frame, MUIV_Frame_InputList
#define PropFrame        MUIA_Frame, MUIV_Frame_Prop
#define SliderFrame      MUIA_Frame, MUIV_Frame_Slider
#define GaugeFrame       MUIA_Frame, MUIV_Frame_Gauge
#define VirtualFrame     MUIA_Frame, MUIV_Frame_Virtual
#define GroupFrame       MUIA_Frame, MUIV_Frame_Group
#define GroupFrameT(s)   MUIA_Frame, MUIV_Frame_Group, MUIA_FrameTitle, s



/***************************************************************************
**
** Spacing Macros
** --------------
**
***************************************************************************/

#define HVSpace           Mui_NewObjectA(MUIC_Rectangle,[TAG_DONE])
#define HSpace(x)         Mui_MakeObjectA(MUIO_HSpace,[x])
#define VSpace(x)         Mui_MakeObjectA(MUIO_VSpace,[x])
#define HCenter(obj)      (HGroup, GroupSpacing(0), Child, HSpace(0), Child, (obj), Child, HSpace(0), End)
#define VCenter(obj)      (VGroup, GroupSpacing(0), Child, VSpace(0), Child, (obj), Child, VSpace(0), End)
#define InnerSpacing(h,v) MUIA_InnerLeft,(h),MUIA_InnerRight,(h),MUIA_InnerTop,(v),MUIA_InnerBottom,(v)
#define GroupSpacing(x)   MUIA_Group_Spacing,x



#ifdef MUI_OBSOLETE

/***************************************************************************
**
** String-Object
** -------------
**
** The following macro creates a simple string gadget.
**
***************************************************************************/

#define StringMUI(contents,maxlen)\
	StringObject,\
		StringFrame,\
		MUIA_String_MaxLen  , maxlen,\
		MUIA_String_Contents, contents,\
		End

#define KeyString(contents,maxlen,controlchar)\
	StringObject,\
		StringFrame,\
		MUIA_ControlChar    , controlchar,\
		MUIA_String_MaxLen  , maxlen,\
		MUIA_String_Contents, contents,\
		End

#endif



#ifdef MUI_OBSOLETE

/***************************************************************************
**
** CheckMark-Object
** ----------------
**
** The following macro creates a checkmark gadget.
**
***************************************************************************/

#define CheckMark(selected)\
	ImageObject,\
		ImageButtonFrame,\
		MUIA_InputMode        , MUIV_InputMode_Toggle,\
		MUIA_Image_Spec       , MUII_CheckMark,\
		MUIA_Image_FreeVert   , MUI_TRUE,\
		MUIA_Selected         , selected,\
		MUIA_Background       , MUII_ButtonBack,\
		MUIA_ShowSelState     , FALSE,\
		End

#define KeyCheckMark(selected,control)\
	ImageObject,\
		ImageButtonFrame,\
		MUIA_InputMode        , MUIV_InputMode_Toggle,\
		MUIA_Image_Spec       , MUII_CheckMark,\
		MUIA_Image_FreeVert   , MUI_TRUE,\
		MUIA_Selected         , selected,\
		MUIA_Background       , MUII_ButtonBack,\
		MUIA_ShowSelState     , FALSE,\
		MUIA_ControlChar      , control,\
		End

#endif


/***************************************************************************
**
** Button-Objects
** --------------
**
** Note: Use small letters for KeyButtons, e.g.
**       KeyButton('Cancel',"c")  and not  KeyButton('Cancel',"C") !!
**
***************************************************************************/

#define SimpleButton(label) Mui_MakeObjectA(MUIO_Button,[label])

#ifdef MUI_OBSOLETE

#define KeyButton(name,key)\
	TextObject,\
		ButtonFrame,\
		MUIA_Text_Contents, name,\
		MUIA_Text_PreParse, '\ec',\
		MUIA_Text_HiChar  , key,\
		MUIA_ControlChar  , key,\
		MUIA_InputMode    , MUIV_InputMode_RelVerify,\
		MUIA_Background   , MUII_ButtonBack,\
		End

#endif


#ifdef MUI_OBSOLETE

/***************************************************************************
**
** Cycle-Object
** ------------
**
***************************************************************************/

#define Cycle(entries)        CycleObject, MUIA_Cycle_Entries, entries, End
#define KeyCycle(entries,key) CycleObject, MUIA_Cycle_Entries, entries, MUIA_ControlChar, key, End



/***************************************************************************
**
** Radio-Object
** ------------
**
***************************************************************************/

#define Radio(name,array)\
	RadioObject,\
		GroupFrameT(name),\
		MUIA_Radio_Entries,array,\
		End

#define KeyRadio(name,array,key)\
	RadioObject,\
		GroupFrameT(name),\
		MUIA_Radio_Entries,array,\
		MUIA_ControlChar, key,\
		End



/***************************************************************************
**
** Slider-Object
** -------------
**
***************************************************************************/


#define Slider(min,max,level)\
	SliderObject,\
		MUIA_Slider_Min  , min,\
		MUIA_Slider_Max  , max,\
		MUIA_Slider_Level, level,\
		End

#define KeySlider(min,max,level,key)\
	SliderObject,\
		MUIA_Slider_Min  , min,\
		MUIA_Slider_Max  , max,\
		MUIA_Slider_Level, level,\
		MUIA_ControlChar , key,\
		End

#endif



/***************************************************************************
**
** Button to be used for popup objects
**
***************************************************************************/

#define PopButton(img) Mui_MakeObjectA(MUIO_PopButton,[img])



/***************************************************************************
**
** Labeling Objects
** ----------------
**
** Labeling objects, e.g. a group of string gadgets,
**
**   Small: |foo   |
**  Normal: |bar   |
**     Big: |foobar|
**    Huge: |barfoo|
**
** is done using a 2 column group:
**
** ColGroup(2),
** 	Child, Label2('Small:' ),
**    Child, StringObject, End,
** 	Child, Label2('Normal:'),
**    Child, StringObject, End,
** 	Child, Label2('Big:'   ),
**    Child, StringObject, End,
** 	Child, Label2('Huge:'  ),
**    Child, StringObject, End,
**    End,
**
** Note that we have three versions of the label macro, depending on
** the frame type of the right hand object:
**
** Label1(): For use with standard frames (e.g. checkmarks).
** Label2(): For use with double high frames (e.g. string gadgets).
** Label() : For use with objects without a frame.
**
** These macros ensure that your label will look fine even if the
** user of your application configured some strange spacing values.
** If you want to use your own labeling, you'll have to pay attention
** on this topic yourself.
**
***************************************************************************/

#define Label(label)   Mui_MakeObjectA(MUIO_Label,[label,0])
#define Label1(label)  Mui_MakeObjectA(MUIO_Label,[label,MUIO_Label_SingleFrame])
#define Label2(label)  Mui_MakeObjectA(MUIO_Label,[label,MUIO_Label_DoubleFrame])
#define LLabel(label)  Mui_MakeObjectA(MUIO_Label,[label,MUIO_Label_LeftAligned])
#define LLabel1(label) Mui_MakeObjectA(MUIO_Label,[label,MUIO_Label_LeftAligned OR MUIO_Label_SingleFrame])
#define LLabel2(label) Mui_MakeObjectA(MUIO_Label,[label,MUIO_Label_LeftAligned OR MUIO_Label_DoubleFrame])

#define KeyLabel(label,key)   Mui_MakeObjectA(MUIO_Label,[label,key])
#define KeyLabel1(label,key)  Mui_MakeObjectA(MUIO_Label,[label,MUIO_Label_SingleFrame OR (key)])
#define KeyLabel2(label,key)  Mui_MakeObjectA(MUIO_Label,[label,MUIO_Label_DoubleFrame OR (key)])
#define KeyLLabel(label,key)  Mui_MakeObjectA(MUIO_Label,[label,MUIO_Label_LeftAligned OR (key)])
#define KeyLLabel1(label,key) Mui_MakeObjectA(MUIO_Label,[label,MUIO_Label_LeftAligned OR MUIO_Label_SingleFrame OR (key)])
#define KeyLLabel2(label,key) Mui_MakeObjectA(MUIO_Label,[label,MUIO_Label_LeftAligned OR MUIO_Label_DoubleFrame OR (key)])



/***************************************************************************
**
** Controlling Objects
** -------------------
**
** set() and get() are two short stubs for BOOPSI GetAttr() and SetAttrs()
** calls:
**
** {
**    char *x;
**
**    set(obj,MUIA_String_Contents,'foobar');
**    get(obj,MUIA_String_Contents,&x);
**
**    printf('gadget contains "%s"\n',x);
** }
**
** nnset() sets an attribute without triggering a possible notification.
**
***************************************************************************/

#define get(obj,attr,store) GetAttr(attr,obj,store)
#define set(obj,attr,value) SetAttrsA(obj,NEW [attr,value,TAG_DONE])
#define nnset(obj,attr,value) SetAttrsA(obj,NEW [MUIA_NoNotify,MUI_TRUE,attr,value,TAG_DONE])

#define setmutex(obj,n)     set(obj,MUIA_Radio_Active,n)
#define setcycle(obj,n)     set(obj,MUIA_Cycle_Active,n)
#define setstring(obj,s)    set(obj,MUIA_String_Contents,s)
#define setcheckmark(obj,b) set(obj,MUIA_Selected,b)
#define setslider(obj,l)    set(obj,MUIA_Slider_Level,l)

#endif /* MUI_NOSHORTCUTS */


/***************************************************************************
**
** For Boopsi Image Implementors Only:
**
** If MUI is using a boopsi image object, it will send a special method
** immediately after object creation. This method has a parameter structure
** where the boopsi can fill in its minimum and maximum size and learn if
** its used in a horizontal or vertical context.
**
** The boopsi image must use the method id (MUIM_BoopsiQuery) as return
** value. That's how MUI sees that the method is implemented.
**
** Note: MUI does not depend on this method. If the boopsi image doesn't
**       implement it, minimum size will be 0 and maximum size unlimited.
**
***************************************************************************/

CONST MUIM_BoopsiQuery = $80427157 /* this is send to the boopsi and */
                                    /* must be used as return value   */

OBJECT mui_boopsiquery
	mbq_methodid   : LONG
	mbq_screen     : PTR TO screen
	mbq_flags      : LONG
	mbq_minwidth   : LONG
	mbq_minheight  : LONG
	mbq_maxwidth   : LONG
	mbq_maxheight  : LONG
	mbq_defwidth   : LONG
	mbq_defheight  : LONG
	mbq_renderinfo : PTR TO mui_renderinfo
ENDOBJECT

#define MUIP_BoopsiQuery  MUI_BoopsiQuery  /* old structure name */

CONST MBQF_HORIZ = 1           /* object used in a horizontal */
                                    /* context (else vertical)     */

CONST MBQ_MUI_MAXMAX = 10000          /* use this for unlimited MaxWidth/Height */


/*******************************************/
/* Begin of automatic header file creation */
/*******************************************/




/****************************************************************************/
/** Notify                                                                 **/
/****************************************************************************/

#define MUIC_Notify 'Notify.mui'

/* Methods */

CONST MUIM_CallHook                  = $8042b96b /* V4  */
CONST MUIM_FindUData                 = $8042c196 /* V8  */
CONST MUIM_GetUData                  = $8042ed0c /* V8  */
CONST MUIM_KillNotify                = $8042d240 /* V4  */
CONST MUIM_MultiSet                  = $8042d356 /* V7  */
CONST MUIM_NoNotifySet               = $8042216f /* V9  */
CONST MUIM_Notify                    = $8042c9cb /* V4  */
CONST MUIM_Set                       = $8042549a /* V4  */
CONST MUIM_SetAsString               = $80422590 /* V4  */
CONST MUIM_SetUData                  = $8042c920 /* V8  */
CONST MUIM_WriteLong                 = $80428d86 /* V6  */
CONST MUIM_WriteString               = $80424bf4 /* V6  */

/* Attributes */

CONST MUIA_AppMessage                 = $80421955 /* V5  ..g struct AppMessage * */
#ifdef MUI_OBSOLETE
CONST MUIA_HelpFile                   = $80423a6e /* V4  isg STRPTR            */
#endif /* MUI_OBSOLETE */
CONST MUIA_HelpLine                   = $8042a825 /* V4  isg LONG              */
CONST MUIA_HelpNode                   = $80420b85 /* V4  isg STRPTR            */
CONST MUIA_NoNotify                   = $804237f9 /* V7  .s. BOOL              */
CONST MUIA_Revision                   = $80427eaa /* V4  ..g LONG              */
CONST MUIA_UserData                   = $80420313 /* V4  isg ULONG             */
CONST MUIA_Version                    = $80422301 /* V4  ..g LONG              */



/****************************************************************************/
/** Family                                                                 **/
/****************************************************************************/

#define MUIC_Family 'Family.mui'

/* Methods */

CONST MUIM_Family_AddHead            = $8042e200 /* V8  */
CONST MUIM_Family_AddTail            = $8042d752 /* V8  */
CONST MUIM_Family_Insert             = $80424d34 /* V8  */
CONST MUIM_Family_Remove             = $8042f8a9 /* V8  */
CONST MUIM_Family_Sort               = $80421c49 /* V8  */
CONST MUIM_Family_Transfer           = $8042c14a /* V8  */

/* Attributes */

CONST MUIA_Family_Child               = $8042c696 /* V8  i.. Object *          */



/****************************************************************************/
/** Menustrip                                                              **/
/****************************************************************************/

#define MUIC_Menustrip 'Menustrip.mui'

/* Methods */


/* Attributes */

CONST MUIA_Menustrip_Enabled          = $8042815b /* V8  isg BOOL              */



/****************************************************************************/
/** Menu                                                                   **/
/****************************************************************************/

#define MUIC_Menu 'Menu.mui'

/* Methods */


/* Attributes */

CONST MUIA_Menu_Enabled               = $8042ed48 /* V8  isg BOOL              */
CONST MUIA_Menu_Title                 = $8042a0e3 /* V8  isg STRPTR            */



/****************************************************************************/
/** Menuitem                                                               **/
/****************************************************************************/

#define MUIC_Menuitem 'Menuitem.mui'

/* Methods */


/* Attributes */

CONST MUIA_Menuitem_Checked           = $8042562a /* V8  isg BOOL              */
CONST MUIA_Menuitem_Checkit           = $80425ace /* V8  isg BOOL              */
CONST MUIA_Menuitem_Enabled           = $8042ae0f /* V8  isg BOOL              */
CONST MUIA_Menuitem_Exclude           = $80420bc6 /* V8  isg LONG              */
CONST MUIA_Menuitem_Shortcut          = $80422030 /* V8  isg char              */
CONST MUIA_Menuitem_Title             = $804218be /* V8  isg STRPTR            */
CONST MUIA_Menuitem_Toggle            = $80424d5c /* V8  isg BOOL              */
CONST MUIA_Menuitem_Trigger           = $80426f32 /* V8  ..g struct MenuItem * */



/****************************************************************************/
/** Application                                                            **/
/****************************************************************************/

#define MUIC_Application 'Application.mui'

/* Methods */

#ifdef MUI_OBSOLETE
CONST MUIM_Application_GetMenuCheck  = $8042c0a7 /* V4  */
#endif /* MUI_OBSOLETE */
#ifdef MUI_OBSOLETE
CONST MUIM_Application_GetMenuState  = $8042a58f /* V4  */
#endif /* MUI_OBSOLETE */
CONST MUIM_Application_Input         = $8042d0f5 /* V4  */
CONST MUIM_Application_InputBuffered = $80427e59 /* V4  */
CONST MUIM_Application_Load          = $8042f90d /* V4  */
CONST MUIM_Application_PushMethod    = $80429ef8 /* V4  */
CONST MUIM_Application_ReturnID      = $804276ef /* V4  */
CONST MUIM_Application_Save          = $804227ef /* V4  */
#ifdef MUI_OBSOLETE
CONST MUIM_Application_SetMenuCheck  = $8042a707 /* V4  */
#endif /* MUI_OBSOLETE */
#ifdef MUI_OBSOLETE
CONST MUIM_Application_SetMenuState  = $80428bef /* V4  */
#endif /* MUI_OBSOLETE */
CONST MUIM_Application_ShowHelp      = $80426479 /* V4  */

/* Attributes */

CONST MUIA_Application_Active         = $804260ab /* V4  isg BOOL              */
CONST MUIA_Application_Author         = $80424842 /* V4  i.g STRPTR            */
CONST MUIA_Application_Base           = $8042e07a /* V4  i.g STRPTR            */
CONST MUIA_Application_Broker         = $8042dbce /* V4  ..g Broker *          */
CONST MUIA_Application_BrokerHook     = $80428f4b /* V4  isg struct Hook *     */
CONST MUIA_Application_BrokerPort     = $8042e0ad /* V6  ..g struct MsgPort *  */
CONST MUIA_Application_BrokerPri      = $8042c8d0 /* V6  i.g LONG              */
CONST MUIA_Application_Commands       = $80428648 /* V4  isg struct MUI_Command * */
CONST MUIA_Application_Copyright      = $8042ef4d /* V4  i.g STRPTR            */
CONST MUIA_Application_Description    = $80421fc6 /* V4  i.g STRPTR            */
CONST MUIA_Application_DiskObject     = $804235cb /* V4  isg struct DiskObject * */
CONST MUIA_Application_DoubleStart    = $80423bc6 /* V4  ..g BOOL              */
CONST MUIA_Application_DropObject     = $80421266 /* V5  is. Object *          */
CONST MUIA_Application_ForceQuit      = $804257df /* V8  ..g BOOL              */
CONST MUIA_Application_HelpFile       = $804293f4 /* V8  isg STRPTR            */
CONST MUIA_Application_Iconified      = $8042a07f /* V4  .sg BOOL              */
#ifdef MUI_OBSOLETE
CONST MUIA_Application_Menu           = $80420e1f /* V4  i.g struct NewMenu *  */
#endif /* MUI_OBSOLETE */
CONST MUIA_Application_MenuAction     = $80428961 /* V4  ..g ULONG             */
CONST MUIA_Application_MenuHelp       = $8042540b /* V4  ..g ULONG             */
CONST MUIA_Application_Menustrip      = $804252d9 /* V8  i.. Object *          */
CONST MUIA_Application_RexxHook       = $80427c42 /* V7  isg struct Hook *     */
CONST MUIA_Application_RexxMsg        = $8042fd88 /* V4  ..g struct RxMsg *    */
CONST MUIA_Application_RexxString     = $8042d711 /* V4  .s. STRPTR            */
CONST MUIA_Application_SingleTask     = $8042a2c8 /* V4  i.. BOOL              */
CONST MUIA_Application_Sleep          = $80425711 /* V4  .s. BOOL              */
CONST MUIA_Application_Title          = $804281b8 /* V4  i.g STRPTR            */
CONST MUIA_Application_UseCommodities = $80425ee5 /* V10 i.. BOOL              */
CONST MUIA_Application_UseRexx        = $80422387 /* V10 i.. BOOL              */
CONST MUIA_Application_Version        = $8042b33f /* V4  i.g STRPTR            */
CONST MUIA_Application_Window         = $8042bfe0 /* V4  i.. Object *          */



/****************************************************************************/
/** Window                                                                 **/
/****************************************************************************/

#define MUIC_Window 'Window.mui'

/* Methods */

#ifdef MUI_OBSOLETE
CONST MUIM_Window_GetMenuCheck       = $80420414 /* V4  */
#endif /* MUI_OBSOLETE */
#ifdef MUI_OBSOLETE
CONST MUIM_Window_GetMenuState       = $80420d2f /* V4  */
#endif /* MUI_OBSOLETE */
CONST MUIM_Window_ScreenToBack       = $8042913d /* V4  */
CONST MUIM_Window_ScreenToFront      = $804227a4 /* V4  */
CONST MUIM_Window_SetCycleChain      = $80426510 /* V4  */
#ifdef MUI_OBSOLETE
CONST MUIM_Window_SetMenuCheck       = $80422243 /* V4  */
#endif /* MUI_OBSOLETE */
#ifdef MUI_OBSOLETE
CONST MUIM_Window_SetMenuState       = $80422b5e /* V4  */
#endif /* MUI_OBSOLETE */
CONST MUIM_Window_ToBack             = $8042152e /* V4  */
CONST MUIM_Window_ToFront            = $8042554f /* V4  */

/* Attributes */

CONST MUIA_Window_Activate            = $80428d2f /* V4  isg BOOL              */
CONST MUIA_Window_ActiveObject        = $80427925 /* V4  .sg Object *          */
CONST MUIA_Window_AltHeight           = $8042cce3 /* V4  i.g LONG              */
CONST MUIA_Window_AltLeftEdge         = $80422d65 /* V4  i.g LONG              */
CONST MUIA_Window_AltTopEdge          = $8042e99b /* V4  i.g LONG              */
CONST MUIA_Window_AltWidth            = $804260f4 /* V4  i.g LONG              */
CONST MUIA_Window_AppWindow           = $804280cf /* V5  i.. BOOL              */
CONST MUIA_Window_Backdrop            = $8042c0bb /* V4  i.. BOOL              */
CONST MUIA_Window_Borderless          = $80429b79 /* V4  i.. BOOL              */
CONST MUIA_Window_CloseGadget         = $8042a110 /* V4  i.. BOOL              */
CONST MUIA_Window_CloseRequest        = $8042e86e /* V4  ..g BOOL              */
CONST MUIA_Window_DefaultObject       = $804294d7 /* V4  isg Object *          */
CONST MUIA_Window_DepthGadget         = $80421923 /* V4  i.. BOOL              */
CONST MUIA_Window_DragBar             = $8042045d /* V4  i.. BOOL              */
CONST MUIA_Window_FancyDrawing        = $8042bd0e /* V8  isg BOOL              */
CONST MUIA_Window_Height              = $80425846 /* V4  i.g LONG              */
CONST MUIA_Window_ID                  = $804201bd /* V4  isg ULONG             */
CONST MUIA_Window_InputEvent          = $804247d8 /* V4  ..g struct InputEvent * */
CONST MUIA_Window_LeftEdge            = $80426c65 /* V4  i.g LONG              */
#ifdef MUI_OBSOLETE
CONST MUIA_Window_Menu                = $8042db94 /* V4  i.. struct NewMenu *  */
#endif /* MUI_OBSOLETE */
CONST MUIA_Window_MenuAction          = $80427521 /* V8  isg ULONG             */
CONST MUIA_Window_Menustrip           = $8042855e /* V8  i.. Object *          */
CONST MUIA_Window_MouseObject         = $8042bf9b /* V10 ..g Object *          */
CONST MUIA_Window_NeedsMouseObject    = $8042372a /* V10 i.. BOOL              */
CONST MUIA_Window_NoMenus             = $80429df5 /* V4  is. BOOL              */
CONST MUIA_Window_Open                = $80428aa0 /* V4  .sg BOOL              */
CONST MUIA_Window_PublicScreen        = $804278e4 /* V6  isg STRPTR            */
CONST MUIA_Window_RefWindow           = $804201f4 /* V4  is. Object *          */
CONST MUIA_Window_RootObject          = $8042cba5 /* V4  i.. Object *          */
CONST MUIA_Window_Screen              = $8042df4f /* V4  isg struct Screen *   */
CONST MUIA_Window_ScreenTitle         = $804234b0 /* V5  isg STRPTR            */
CONST MUIA_Window_SizeGadget          = $8042e33d /* V4  i.. BOOL              */
CONST MUIA_Window_SizeRight           = $80424780 /* V4  i.. BOOL              */
CONST MUIA_Window_Sleep               = $8042e7db /* V4  .sg BOOL              */
CONST MUIA_Window_Title               = $8042ad3d /* V4  isg STRPTR            */
CONST MUIA_Window_TopEdge             = $80427c66 /* V4  i.g LONG              */
CONST MUIA_Window_Width               = $8042dcae /* V4  i.g LONG              */
CONST MUIA_Window_Window              = $80426a42 /* V4  ..g struct Window *   */

CONST MUIV_Window_ActiveObject_None = 0
CONST MUIV_Window_ActiveObject_Next = -1
CONST MUIV_Window_ActiveObject_Prev = -2
#define MUIV_Window_AltHeight_MinMax(p) (0-(p))
#define MUIV_Window_AltHeight_Visible(p) (-100-(p))
#define MUIV_Window_AltHeight_Screen(p) (-200-(p))
CONST MUIV_Window_AltHeight_Scaled = -1000
CONST MUIV_Window_AltLeftEdge_Centered = -1
CONST MUIV_Window_AltLeftEdge_Moused = -2
CONST MUIV_Window_AltLeftEdge_NoChange = -1000
CONST MUIV_Window_AltTopEdge_Centered = -1
CONST MUIV_Window_AltTopEdge_Moused = -2
#define MUIV_Window_AltTopEdge_Delta(p) (-3-(p))
CONST MUIV_Window_AltTopEdge_NoChange = -1000
#define MUIV_Window_AltWidth_MinMax(p) (0-(p))
#define MUIV_Window_AltWidth_Visible(p) (-100-(p))
#define MUIV_Window_AltWidth_Screen(p) (-200-(p))
CONST MUIV_Window_AltWidth_Scaled = -1000
#define MUIV_Window_Height_MinMax(p) (0-(p))
#define MUIV_Window_Height_Visible(p) (-100-(p))
#define MUIV_Window_Height_Screen(p) (-200-(p))
CONST MUIV_Window_Height_Scaled = -1000
CONST MUIV_Window_Height_Default = -1001
CONST MUIV_Window_LeftEdge_Centered = -1
CONST MUIV_Window_LeftEdge_Moused = -2
#ifdef MUI_OBSOLETE
CONST MUIV_Window_Menu_NoMenu = -1
#endif /* MUI_OBSOLETE */
CONST MUIV_Window_TopEdge_Centered = -1
CONST MUIV_Window_TopEdge_Moused = -2
#define MUIV_Window_TopEdge_Delta(p) (-3-(p))
#define MUIV_Window_Width_MinMax(p) (0-(p))
#define MUIV_Window_Width_Visible(p) (-100-(p))
#define MUIV_Window_Width_Screen(p) (-200-(p))
CONST MUIV_Window_Width_Scaled = -1000
CONST MUIV_Window_Width_Default = -1001


/****************************************************************************/
/** Area                                                                   **/
/****************************************************************************/

#define MUIC_Area 'Area.mui'

/* Methods */

CONST MUIM_AskMinMax                 = $80423874 /* Custom Class */ /* V4  */
CONST MUIM_Cleanup                   = $8042d985 /* Custom Class */ /* V4  */
CONST MUIM_Draw                      = $80426f3f /* Custom Class */ /* V4  */
CONST MUIM_HandleInput               = $80422a1a /* Custom Class */ /* V4  */
CONST MUIM_Hide                      = $8042f20f /* Custom Class */ /* V4  */
CONST MUIM_Setup                     = $80428354 /* Custom Class */ /* V4  */
CONST MUIM_Show                      = $8042cc84 /* Custom Class */ /* V4  */

/* Attributes */

CONST MUIA_ApplicationObject          = $8042d3ee /* V4  ..g Object *          */
CONST MUIA_Background                 = $8042545b /* V4  is. LONG              */
CONST MUIA_BottomEdge                 = $8042e552 /* V4  ..g LONG              */
CONST MUIA_ControlChar                = $8042120b /* V4  i.. char              */
CONST MUIA_Disabled                   = $80423661 /* V4  isg BOOL              */
CONST MUIA_ExportID                   = $8042d76e /* V4  isg LONG              */
CONST MUIA_FixHeight                  = $8042a92b /* V4  i.. LONG              */
CONST MUIA_FixHeightTxt               = $804276f2 /* V4  i.. LONG              */
CONST MUIA_FixWidth                   = $8042a3f1 /* V4  i.. LONG              */
CONST MUIA_FixWidthTxt                = $8042d044 /* V4  i.. STRPTR            */
CONST MUIA_Font                       = $8042be50 /* V4  i.g struct TextFont * */
CONST MUIA_Frame                      = $8042ac64 /* V4  i.. LONG              */
CONST MUIA_FramePhantomHoriz          = $8042ed76 /* V4  i.. BOOL              */
CONST MUIA_FrameTitle                 = $8042d1c7 /* V4  i.. STRPTR            */
CONST MUIA_Height                     = $80423237 /* V4  ..g LONG              */
CONST MUIA_HorizWeight                = $80426db9 /* V4  i.. WORD              */
CONST MUIA_InnerBottom                = $8042f2c0 /* V4  i.. LONG              */
CONST MUIA_InnerLeft                  = $804228f8 /* V4  i.. LONG              */
CONST MUIA_InnerRight                 = $804297ff /* V4  i.. LONG              */
CONST MUIA_InnerTop                   = $80421eb6 /* V4  i.. LONG              */
CONST MUIA_InputMode                  = $8042fb04 /* V4  i.. LONG              */
CONST MUIA_LeftEdge                   = $8042bec6 /* V4  ..g LONG              */
CONST MUIA_Pressed                    = $80423535 /* V4  ..g BOOL              */
CONST MUIA_RightEdge                  = $8042ba82 /* V4  ..g LONG              */
CONST MUIA_Selected                   = $8042654b /* V4  isg BOOL              */
CONST MUIA_ShowMe                     = $80429ba8 /* V4  isg BOOL              */
CONST MUIA_ShowSelState               = $8042caac /* V4  i.. BOOL              */
CONST MUIA_Timer                      = $80426435 /* V4  ..g LONG              */
CONST MUIA_TopEdge                    = $8042509b /* V4  ..g LONG              */
CONST MUIA_VertWeight                 = $804298d0 /* V4  i.. WORD              */
CONST MUIA_Weight                     = $80421d1f /* V4  i.. WORD              */
CONST MUIA_Width                      = $8042b59c /* V4  ..g LONG              */
CONST MUIA_Window                     = $80421591 /* V4  ..g struct Window *   */
CONST MUIA_WindowObject               = $8042669e /* V4  ..g Object *          */

CONST MUIV_Font_Inherit = 0
CONST MUIV_Font_Normal = -1
CONST MUIV_Font_List = -2
CONST MUIV_Font_Tiny = -3
CONST MUIV_Font_Fixed = -4
CONST MUIV_Font_Title = -5
CONST MUIV_Font_Big = -6
CONST MUIV_Frame_None = 0
CONST MUIV_Frame_Button = 1
CONST MUIV_Frame_ImageButton = 2
CONST MUIV_Frame_Text = 3
CONST MUIV_Frame_String = 4
CONST MUIV_Frame_ReadList = 5
CONST MUIV_Frame_InputList = 6
CONST MUIV_Frame_Prop = 7
CONST MUIV_Frame_Gauge = 8
CONST MUIV_Frame_Group = 9
CONST MUIV_Frame_PopUp = 10
CONST MUIV_Frame_Virtual = 11
CONST MUIV_Frame_Slider = 12
CONST MUIV_Frame_Count = 13
CONST MUIV_InputMode_None = 0
CONST MUIV_InputMode_RelVerify = 1
CONST MUIV_InputMode_Immediate = 2


/****************************************************************************/
/** Rectangle                                                              **/
/****************************************************************************/

#define MUIC_Rectangle 'Rectangle.mui'

/* Attributes */

CONST MUIA_Rectangle_HBar             = $8042c943 /* V7  i.g BOOL              */
CONST MUIA_Rectangle_VBar             = $80422204 /* V7  i.g BOOL              */



/****************************************************************************/
/** Image                                                                  **/
/****************************************************************************/

#define MUIC_Image 'Image.mui'

/* Attributes */

CONST MUIA_Image_FontMatch            = $8042815d /* V4  i.. BOOL              */
CONST MUIA_Image_FontMatchHeight      = $80429f26 /* V4  i.. BOOL              */
CONST MUIA_Image_FontMatchWidth       = $804239bf /* V4  i.. BOOL              */
CONST MUIA_Image_FreeHoriz            = $8042da84 /* V4  i.. BOOL              */
CONST MUIA_Image_FreeVert             = $8042ea28 /* V4  i.. BOOL              */
CONST MUIA_Image_OldImage             = $80424f3d /* V4  i.. struct Image *    */
CONST MUIA_Image_Spec                 = $804233d5 /* V4  i.. char *            */
CONST MUIA_Image_State                = $8042a3ad /* V4  is. LONG              */



/****************************************************************************/
/** Bitmap                                                                 **/
/****************************************************************************/

#define MUIC_Bitmap 'Bitmap.mui'

/* Attributes */

CONST MUIA_Bitmap_Bitmap              = $804279bd /* V8  isg struct BitMap *   */
CONST MUIA_Bitmap_Height              = $80421560 /* V8  isg LONG              */
CONST MUIA_Bitmap_MappingTable        = $8042e23d /* V8  isg UBYTE *           */
CONST MUIA_Bitmap_SourceColors        = $80425360 /* V8  isg ULONG *           */
CONST MUIA_Bitmap_Transparent         = $80422805 /* V8  isg LONG              */
CONST MUIA_Bitmap_Width               = $8042eb3a /* V8  isg LONG              */



/****************************************************************************/
/** Bodychunk                                                              **/
/****************************************************************************/

#define MUIC_Bodychunk 'Bodychunk.mui'

/* Attributes */

CONST MUIA_Bodychunk_Body             = $8042ca67 /* V8  isg UBYTE *           */
CONST MUIA_Bodychunk_Compression      = $8042de5f /* V8  isg UBYTE             */
CONST MUIA_Bodychunk_Depth            = $8042c392 /* V8  isg LONG              */
CONST MUIA_Bodychunk_Masking          = $80423b0e /* V8  isg UBYTE             */



/****************************************************************************/
/** Text                                                                   **/
/****************************************************************************/

#define MUIC_Text 'Text.mui'

/* Attributes */

CONST MUIA_Text_Contents              = $8042f8dc /* V4  isg STRPTR            */
CONST MUIA_Text_HiChar                = $804218ff /* V4  i.. char              */
CONST MUIA_Text_PreParse              = $8042566d /* V4  isg STRPTR            */
CONST MUIA_Text_SetMax                = $80424d0a /* V4  i.. BOOL              */
CONST MUIA_Text_SetMin                = $80424e10 /* V4  i.. BOOL              */



/****************************************************************************/
/** String                                                                 **/
/****************************************************************************/

#define MUIC_String 'String.mui'

/* Attributes */

CONST MUIA_String_Accept              = $8042e3e1 /* V4  isg STRPTR            */
CONST MUIA_String_Acknowledge         = $8042026c /* V4  ..g STRPTR            */
CONST MUIA_String_AttachedList        = $80420fd2 /* V4  i.. Object *          */
CONST MUIA_String_BufferPos           = $80428b6c /* V4  .sg LONG              */
CONST MUIA_String_Contents            = $80428ffd /* V4  isg STRPTR            */
CONST MUIA_String_DisplayPos          = $8042ccbf /* V4  .sg LONG              */
CONST MUIA_String_EditHook            = $80424c33 /* V7  isg struct Hook *     */
CONST MUIA_String_Format              = $80427484 /* V4  i.g LONG              */
CONST MUIA_String_Integer             = $80426e8a /* V4  isg ULONG             */
CONST MUIA_String_MaxLen              = $80424984 /* V4  i.g LONG              */
CONST MUIA_String_Reject              = $8042179c /* V4  isg STRPTR            */
CONST MUIA_String_Secret              = $80428769 /* V4  i.g BOOL              */

CONST MUIV_String_Format_Left = 0
CONST MUIV_String_Format_Center = 1
CONST MUIV_String_Format_Right = 2


/****************************************************************************/
/** Prop                                                                   **/
/****************************************************************************/

#define MUIC_Prop 'Prop.mui'

/* Attributes */

CONST MUIA_Prop_Entries               = $8042fbdb /* V4  isg LONG              */
CONST MUIA_Prop_First                 = $8042d4b2 /* V4  isg LONG              */
CONST MUIA_Prop_Horiz                 = $8042f4f3 /* V4  i.g BOOL              */
CONST MUIA_Prop_Slider                = $80429c3a /* V4  isg BOOL              */
CONST MUIA_Prop_Visible               = $8042fea6 /* V4  isg LONG              */



/****************************************************************************/
/** Gauge                                                                  **/
/****************************************************************************/

#define MUIC_Gauge 'Gauge.mui'

/* Attributes */

CONST MUIA_Gauge_Current              = $8042f0dd /* V4  isg LONG              */
CONST MUIA_Gauge_Divide               = $8042d8df /* V4  isg BOOL              */
CONST MUIA_Gauge_Horiz                = $804232dd /* V4  i.. BOOL              */
CONST MUIA_Gauge_InfoText             = $8042bf15 /* V7  isg char *            */
CONST MUIA_Gauge_Max                  = $8042bcdb /* V4  isg LONG              */



/****************************************************************************/
/** Scale                                                                  **/
/****************************************************************************/

#define MUIC_Scale 'Scale.mui'

/* Attributes */

CONST MUIA_Scale_Horiz                = $8042919a /* V4  isg BOOL              */



/****************************************************************************/
/** Boopsi                                                                 **/
/****************************************************************************/

#define MUIC_Boopsi 'Boopsi.mui'

/* Attributes */

CONST MUIA_Boopsi_Class               = $80426999 /* V4  isg struct IClass *   */
CONST MUIA_Boopsi_ClassID             = $8042bfa3 /* V4  isg char *            */
CONST MUIA_Boopsi_MaxHeight           = $8042757f /* V4  isg ULONG             */
CONST MUIA_Boopsi_MaxWidth            = $8042bcb1 /* V4  isg ULONG             */
CONST MUIA_Boopsi_MinHeight           = $80422c93 /* V4  isg ULONG             */
CONST MUIA_Boopsi_MinWidth            = $80428fb2 /* V4  isg ULONG             */
CONST MUIA_Boopsi_Object              = $80420178 /* V4  ..g Object *          */
CONST MUIA_Boopsi_Remember            = $8042f4bd /* V4  i.. ULONG             */
CONST MUIA_Boopsi_Smart               = $8042b8d7 /* V9  i.. BOOL              */
CONST MUIA_Boopsi_TagDrawInfo         = $8042bae7 /* V4  isg ULONG             */
CONST MUIA_Boopsi_TagScreen           = $8042bc71 /* V4  isg ULONG             */
CONST MUIA_Boopsi_TagWindow           = $8042e11d /* V4  isg ULONG             */



/****************************************************************************/
/** Colorfield                                                             **/
/****************************************************************************/

#define MUIC_Colorfield 'Colorfield.mui'

/* Attributes */

CONST MUIA_Colorfield_Blue            = $8042d3b0 /* V4  isg ULONG             */
CONST MUIA_Colorfield_Green           = $80424466 /* V4  isg ULONG             */
CONST MUIA_Colorfield_Pen             = $8042713a /* V4  ..g ULONG             */
CONST MUIA_Colorfield_Red             = $804279f6 /* V4  isg ULONG             */
CONST MUIA_Colorfield_RGB             = $8042677a /* V4  isg ULONG *           */



/****************************************************************************/
/** List                                                                   **/
/****************************************************************************/

#define MUIC_List 'List.mui'

/* Methods */

CONST MUIM_List_Clear                = $8042ad89 /* V4  */
CONST MUIM_List_Exchange             = $8042468c /* V4  */
CONST MUIM_List_GetEntry             = $804280ec /* V4  */
CONST MUIM_List_Insert               = $80426c87 /* V4  */
CONST MUIM_List_InsertSingle         = $804254d5 /* V7  */
CONST MUIM_List_Jump                 = $8042baab /* V4  */
CONST MUIM_List_Move                 = $804253c2 /* V9  */
CONST MUIM_List_NextSelected         = $80425f17 /* V6  */
CONST MUIM_List_Redraw               = $80427993 /* V4  */
CONST MUIM_List_Remove               = $8042647e /* V4  */
CONST MUIM_List_Select               = $804252d8 /* V4  */
CONST MUIM_List_Sort                 = $80422275 /* V4  */

/* Attributes */

CONST MUIA_List_Active                = $8042391c /* V4  isg LONG              */
CONST MUIA_List_AdjustHeight          = $8042850d /* V4  i.. BOOL              */
CONST MUIA_List_AdjustWidth           = $8042354a /* V4  i.. BOOL              */
CONST MUIA_List_CompareHook           = $80425c14 /* V4  is. struct Hook *     */
CONST MUIA_List_ConstructHook         = $8042894f /* V4  is. struct Hook *     */
CONST MUIA_List_DestructHook          = $804297ce /* V4  is. struct Hook *     */
CONST MUIA_List_DisplayHook           = $8042b4d5 /* V4  is. struct Hook *     */
CONST MUIA_List_Entries               = $80421654 /* V4  ..g LONG              */
CONST MUIA_List_First                 = $804238d4 /* V4  ..g LONG              */
CONST MUIA_List_Format                = $80423c0a /* V4  isg STRPTR            */
CONST MUIA_List_InsertPosition        = $8042d0cd /* V9  ..g LONG              */
CONST MUIA_List_MultiTestHook         = $8042c2c6 /* V4  is. struct Hook *     */
CONST MUIA_List_Quiet                 = $8042d8c7 /* V4  .s. BOOL              */
CONST MUIA_List_SourceArray           = $8042c0a0 /* V4  i.. APTR              */
CONST MUIA_List_Title                 = $80423e66 /* V6  isg char *            */
CONST MUIA_List_Visible               = $8042191f /* V4  ..g LONG              */

CONST MUIV_List_Active_Off = -1
CONST MUIV_List_Active_Top = -2
CONST MUIV_List_Active_Bottom = -3
CONST MUIV_List_Active_Up = -4
CONST MUIV_List_Active_Down = -5
CONST MUIV_List_Active_PageUp = -6
CONST MUIV_List_Active_PageDown = -7
CONST MUIV_List_ConstructHook_String = -1
CONST MUIV_List_CopyHook_String = -1
CONST MUIV_List_CursorType_None = 0
CONST MUIV_List_CursorType_Bar = 1
CONST MUIV_List_CursorType_Rect = 2
CONST MUIV_List_DestructHook_String = -1


/****************************************************************************/
/** Floattext                                                              **/
/****************************************************************************/

#define MUIC_Floattext 'Floattext.mui'

/* Attributes */

CONST MUIA_Floattext_Justify          = $8042dc03 /* V4  isg BOOL              */
CONST MUIA_Floattext_SkipChars        = $80425c7d /* V4  is. STRPTR            */
CONST MUIA_Floattext_TabSize          = $80427d17 /* V4  is. LONG              */
CONST MUIA_Floattext_Text             = $8042d16a /* V4  isg STRPTR            */



/****************************************************************************/
/** Volumelist                                                             **/
/****************************************************************************/

#define MUIC_Volumelist 'Volumelist.mui'


/****************************************************************************/
/** Scrmodelist                                                            **/
/****************************************************************************/

#define MUIC_Scrmodelist 'Scrmodelist.mui'

/* Attributes */




/****************************************************************************/
/** Dirlist                                                                **/
/****************************************************************************/

#define MUIC_Dirlist 'Dirlist.mui'

/* Methods */

CONST MUIM_Dirlist_ReRead            = $80422d71 /* V4  */

/* Attributes */

CONST MUIA_Dirlist_AcceptPattern      = $8042760a /* V4  is. STRPTR            */
CONST MUIA_Dirlist_Directory          = $8042ea41 /* V4  isg STRPTR            */
CONST MUIA_Dirlist_DrawersOnly        = $8042b379 /* V4  is. BOOL              */
CONST MUIA_Dirlist_FilesOnly          = $8042896a /* V4  is. BOOL              */
CONST MUIA_Dirlist_FilterDrawers      = $80424ad2 /* V4  is. BOOL              */
CONST MUIA_Dirlist_FilterHook         = $8042ae19 /* V4  is. struct Hook *     */
CONST MUIA_Dirlist_MultiSelDirs       = $80428653 /* V6  is. BOOL              */
CONST MUIA_Dirlist_NumBytes           = $80429e26 /* V4  ..g LONG              */
CONST MUIA_Dirlist_NumDrawers         = $80429cb8 /* V4  ..g LONG              */
CONST MUIA_Dirlist_NumFiles           = $8042a6f0 /* V4  ..g LONG              */
CONST MUIA_Dirlist_Path               = $80426176 /* V4  ..g STRPTR            */
CONST MUIA_Dirlist_RejectIcons        = $80424808 /* V4  is. BOOL              */
CONST MUIA_Dirlist_RejectPattern      = $804259c7 /* V4  is. STRPTR            */
CONST MUIA_Dirlist_SortDirs           = $8042bbb9 /* V4  is. LONG              */
CONST MUIA_Dirlist_SortHighLow        = $80421896 /* V4  is. BOOL              */
CONST MUIA_Dirlist_SortType           = $804228bc /* V4  is. LONG              */
CONST MUIA_Dirlist_Status             = $804240de /* V4  ..g LONG              */

CONST MUIV_Dirlist_SortDirs_First = 0
CONST MUIV_Dirlist_SortDirs_Last = 1
CONST MUIV_Dirlist_SortDirs_Mix = 2
CONST MUIV_Dirlist_SortType_Name = 0
CONST MUIV_Dirlist_SortType_Date = 1
CONST MUIV_Dirlist_SortType_Size = 2
CONST MUIV_Dirlist_Status_Invalid = 0
CONST MUIV_Dirlist_Status_Reading = 1
CONST MUIV_Dirlist_Status_Valid = 2


/****************************************************************************/
/** Group                                                                  **/
/****************************************************************************/

#define MUIC_Group 'Group.mui'

/* Methods */


/* Attributes */

CONST MUIA_Group_ActivePage           = $80424199 /* V5  isg LONG              */
CONST MUIA_Group_Child                = $804226e6 /* V4  i.. Object *          */
CONST MUIA_Group_Columns              = $8042f416 /* V4  is. LONG              */
CONST MUIA_Group_Horiz                = $8042536b /* V4  i.. BOOL              */
CONST MUIA_Group_HorizSpacing         = $8042c651 /* V4  is. LONG              */
CONST MUIA_Group_PageMode             = $80421a5f /* V5  is. BOOL              */
CONST MUIA_Group_Rows                 = $8042b68f /* V4  is. LONG              */
CONST MUIA_Group_SameHeight           = $8042037e /* V4  i.. BOOL              */
CONST MUIA_Group_SameSize             = $80420860 /* V4  i.. BOOL              */
CONST MUIA_Group_SameWidth            = $8042b3ec /* V4  i.. BOOL              */
CONST MUIA_Group_Spacing              = $8042866d /* V4  is. LONG              */
CONST MUIA_Group_VertSpacing          = $8042e1bf /* V4  is. LONG              */

CONST MUIV_Group_ActivePage_First = 0
CONST MUIV_Group_ActivePage_Last = -1
CONST MUIV_Group_ActivePage_Prev = -2
CONST MUIV_Group_ActivePage_Next = -3


/****************************************************************************/
/** Register                                                               **/
/****************************************************************************/

#define MUIC_Register 'Register.mui'

/* Attributes */

CONST MUIA_Register_Frame             = $8042349b /* V7  i.g BOOL              */
CONST MUIA_Register_Titles            = $804297ec /* V7  i.g STRPTR *          */



/****************************************************************************/
/** Virtgroup                                                              **/
/****************************************************************************/

#define MUIC_Virtgroup 'Virtgroup.mui'

/* Methods */


/* Attributes */

CONST MUIA_Virtgroup_Height           = $80423038 /* V6  ..g LONG              */
CONST MUIA_Virtgroup_Left             = $80429371 /* V6  isg LONG              */
CONST MUIA_Virtgroup_Top              = $80425200 /* V6  isg LONG              */
CONST MUIA_Virtgroup_Width            = $80427c49 /* V6  ..g LONG              */



/****************************************************************************/
/** Scrollgroup                                                            **/
/****************************************************************************/

#define MUIC_Scrollgroup 'Scrollgroup.mui'

/* Attributes */

CONST MUIA_Scrollgroup_Contents       = $80421261 /* V4  i.. Object *          */
CONST MUIA_Scrollgroup_FreeHoriz      = $804292f3 /* V9  i.. BOOL              */
CONST MUIA_Scrollgroup_FreeVert       = $804224f2 /* V9  i.. BOOL              */



/****************************************************************************/
/** Scrollbar                                                              **/
/****************************************************************************/

#define MUIC_Scrollbar 'Scrollbar.mui'


/****************************************************************************/
/** Listview                                                               **/
/****************************************************************************/

#define MUIC_Listview 'Listview.mui'

/* Attributes */

CONST MUIA_Listview_ClickColumn       = $8042d1b3 /* V7  ..g LONG              */
CONST MUIA_Listview_DefClickColumn    = $8042b296 /* V7  isg LONG              */
CONST MUIA_Listview_DoubleClick       = $80424635 /* V4  i.g BOOL              */
CONST MUIA_Listview_Input             = $8042682d /* V4  i.. BOOL              */
CONST MUIA_Listview_List              = $8042bcce /* V4  i.. Object *          */
CONST MUIA_Listview_MultiSelect       = $80427e08 /* V7  i.. LONG              */
CONST MUIA_Listview_ScrollerPos       = $8042b1b4 /* V10 i.. BOOL              */
CONST MUIA_Listview_SelectChange      = $8042178f /* V4  ..g BOOL              */

CONST MUIV_Listview_MultiSelect_None = 0
CONST MUIV_Listview_MultiSelect_Default = 1
CONST MUIV_Listview_MultiSelect_Shifted = 2
CONST MUIV_Listview_MultiSelect_Always = 3
CONST MUIV_Listview_ScrollerPos_Default = 0
CONST MUIV_Listview_ScrollerPos_Left = 1
CONST MUIV_Listview_ScrollerPos_Right = 2


/****************************************************************************/
/** Radio                                                                  **/
/****************************************************************************/

#define MUIC_Radio 'Radio.mui'

/* Attributes */

CONST MUIA_Radio_Active               = $80429b41 /* V4  isg LONG              */
CONST MUIA_Radio_Entries              = $8042b6a1 /* V4  i.. STRPTR *          */



/****************************************************************************/
/** Cycle                                                                  **/
/****************************************************************************/

#define MUIC_Cycle 'Cycle.mui'

/* Attributes */

CONST MUIA_Cycle_Active               = $80421788 /* V4  isg LONG              */
CONST MUIA_Cycle_Entries              = $80420629 /* V4  i.. STRPTR *          */

CONST MUIV_Cycle_Active_Next = -1
CONST MUIV_Cycle_Active_Prev = -2


/****************************************************************************/
/** Slider                                                                 **/
/****************************************************************************/

#define MUIC_Slider 'Slider.mui'

/* Attributes */

CONST MUIA_Slider_Level               = $8042ae3a /* V4  isg LONG              */
CONST MUIA_Slider_Max                 = $8042d78a /* V4  isg LONG              */
CONST MUIA_Slider_Min                 = $8042e404 /* V4  isg LONG              */
CONST MUIA_Slider_Quiet               = $80420b26 /* V6  i.. BOOL              */
CONST MUIA_Slider_Reverse             = $8042f2a0 /* V4  isg BOOL              */



/****************************************************************************/
/** Coloradjust                                                            **/
/****************************************************************************/

#define MUIC_Coloradjust 'Coloradjust.mui'

/* Attributes */

CONST MUIA_Coloradjust_Blue           = $8042b8a3 /* V4  isg ULONG             */
CONST MUIA_Coloradjust_Green          = $804285ab /* V4  isg ULONG             */
CONST MUIA_Coloradjust_ModeID         = $8042ec59 /* V4  isg ULONG             */
CONST MUIA_Coloradjust_Red            = $80420eaa /* V4  isg ULONG             */
CONST MUIA_Coloradjust_RGB            = $8042f899 /* V4  isg ULONG *           */



/****************************************************************************/
/** Palette                                                                **/
/****************************************************************************/

#define MUIC_Palette 'Palette.mui'

/* Attributes */

CONST MUIA_Palette_Entries            = $8042a3d8 /* V6  i.g struct MUI_Palette_Entry * */
CONST MUIA_Palette_Groupable          = $80423e67 /* V6  isg BOOL              */
CONST MUIA_Palette_Names              = $8042c3a2 /* V6  isg char **           */



/****************************************************************************/
/** Colorpanel                                                             **/
/****************************************************************************/

#define MUIC_Colorpanel 'Colorpanel.mui'

/* Methods */


/* Attributes */




/****************************************************************************/
/** Popstring                                                              **/
/****************************************************************************/

#define MUIC_Popstring 'Popstring.mui'

/* Methods */

CONST MUIM_Popstring_Close           = $8042dc52 /* V7  */
CONST MUIM_Popstring_Open            = $804258ba /* V7  */

/* Attributes */

CONST MUIA_Popstring_Button           = $8042d0b9 /* V7  i.g Object *          */
CONST MUIA_Popstring_CloseHook        = $804256bf /* V7  isg struct Hook *     */
CONST MUIA_Popstring_OpenHook         = $80429d00 /* V7  isg struct Hook *     */
CONST MUIA_Popstring_String           = $804239ea /* V7  i.g Object *          */
CONST MUIA_Popstring_Toggle           = $80422b7a /* V7  isg BOOL              */



/****************************************************************************/
/** Popobject                                                              **/
/****************************************************************************/

#define MUIC_Popobject 'Popobject.mui'

/* Attributes */

CONST MUIA_Popobject_Follow           = $80424cb5 /* V7  isg BOOL              */
CONST MUIA_Popobject_Light            = $8042a5a3 /* V7  isg BOOL              */
CONST MUIA_Popobject_Object           = $804293e3 /* V7  i.g Object *          */
CONST MUIA_Popobject_ObjStrHook       = $8042db44 /* V7  isg struct Hook *     */
CONST MUIA_Popobject_StrObjHook       = $8042fbe1 /* V7  isg struct Hook *     */
CONST MUIA_Popobject_Volatile         = $804252ec /* V7  isg BOOL              */
CONST MUIA_Popobject_WindowHook       = $8042f194 /* V9  isg struct Hook *     */



/****************************************************************************/
/** Poplist                                                                **/
/****************************************************************************/

#define MUIC_Poplist 'Poplist.mui'

/* Attributes */

CONST MUIA_Poplist_Array              = $8042084c /* V8  i.. char **           */



/****************************************************************************/
/** Popasl                                                                 **/
/****************************************************************************/

#define MUIC_Popasl 'Popasl.mui'

/* Attributes */

CONST MUIA_Popasl_Active              = $80421b37 /* V7  ..g BOOL              */
CONST MUIA_Popasl_StartHook           = $8042b703 /* V7  isg struct Hook *     */
CONST MUIA_Popasl_StopHook            = $8042d8d2 /* V7  isg struct Hook *     */
CONST MUIA_Popasl_Type                = $8042df3d /* V7  i.g ULONG             */



/*****************************************/
/* End of automatic header file creation */
/*****************************************/







/*************************************************************************
** Structures and Macros for creating custom classes.
*************************************************************************/


/*
** GENERAL NOTES:
**
** - Everything described in this header file is only valid within
**   MUI classes. You may never use any of these things out of
**   a class, e.g. in a traditional MUI application.
**
** - Except when otherwise stated, all structures are strictly read only.
*/


/* Global information for every object */

OBJECT mui_globalinfo
	priv0                 : LONG
	mgi_applicationobject : PTR TO LONG
ENDOBJECT


/* Instance data of notify class */

OBJECT mui_notifydata
	mnd_globalinfo : PTR TO mui_globalinfo
	mnd_userdata   : LONG
	priv1          : LONG
	priv2          : LONG
	priv3          : LONG
	priv4          : LONG
	priv5          : LONG
ENDOBJECT


/* MUI_MinMax structure holds information about minimum, maximum
   and default dimensions of an object. */

OBJECT mui_minmax
	minwidth  : INT
	minheight : INT
	maxwidth  : INT
	maxheight : INT
	defwidth  : INT
	defheight : INT
ENDOBJECT

CONST MUI_MAXMAX = 10000 /* use this if a dimension is not limited. */


/* (partial) instance data of area class */

OBJECT mui_areadata
	mad_renderinfo : PTR TO mui_renderinfo
	priv6          : LONG
	mad_font       : PTR TO textfont
	mad_minmax     : mui_minmax
	mad_box        : ibox
	mad_addleft    : CHAR
	mad_addtop     : CHAR
	mad_subwidth   : CHAR
	mad_subheight  : CHAR
	mad_flags      : LONG
ENDOBJECT

/* Definitions for mad_Flags, other flags are private */

CONST MADF_DRAWOBJECT        = 1 /* completely redraw yourself */
CONST MADF_DRAWUPDATE        = 2 /* only update yourself */




/* MUI's draw pens */

CONST MPEN_SHINE      = 0
CONST MPEN_HALFSHINE  = 1
CONST MPEN_BACKGROUND = 2
CONST MPEN_HALFSHADOW = 3
CONST MPEN_SHADOW     = 4
CONST MPEN_TEXT       = 5
CONST MPEN_FILL       = 6
CONST MPEN_ACTIVEOBJ  = 7
CONST MPEN_COUNT      = 8


/* Information on display environment */

OBJECT mui_renderinfo
	mri_windowobject : PTR TO LONG
	mri_screen       : PTR TO screen
	mri_drawinfo     : PTR TO drawinfo
	mri_pens         : PTR TO INT
	mri_window       : PTR TO window
	mri_rastport     : PTR TO rastport
ENDOBJECT



/* the following macros can be used to get pointers to an objects
   GlobalInfo and RenderInfo structures. */

OBJECT __dummyxfc2__
	mnd : mui_notifydata
	mad : mui_areadata
ENDOBJECT

#define muiNotifyData(obj) obj::__dummyxfc2__.mnd
#define muiAreaData(obj)   obj::__dummyxfc2__.mad

#define muiGlobalInfo(obj) obj::__dummyxfc2__.mnd.mnd_globalinfo
#define muiUserData(obj)   obj::__dummyxfc2__.mnd.mnd_userdata
#define muiRenderInfo(obj) obj::__dummyxfc2__.mad.mad_renderinfo



/* User configurable keyboard events coming with MUIM_HandleInput */

CONST	MUIKEY_RELEASE = -2, /* not a real key, faked when MUIKEY_PRESS is released */
	MUIKEY_NONE    = -1
ENUM	MUIKEY_PRESS,
	MUIKEY_TOGGLE,
	MUIKEY_UP,
	MUIKEY_DOWN,
	MUIKEY_PAGEUP,
	MUIKEY_PAGEDOWN,
	MUIKEY_TOP,
	MUIKEY_BOTTOM,
	MUIKEY_LEFT,
	MUIKEY_RIGHT,
	MUIKEY_WORDLEFT,
	MUIKEY_WORDRIGHT,
	MUIKEY_LINESTART,
	MUIKEY_LINEEND,
	MUIKEY_GADGET_NEXT,
	MUIKEY_GADGET_PREV,
	MUIKEY_GADGET_OFF,
	MUIKEY_WINDOW_CLOSE,
	MUIKEY_WINDOW_NEXT,
	MUIKEY_WINDOW_PREV,
	MUIKEY_HELP,
	MUIKEY_POPUP,
	MUIKEY_COUNT /* counter */


/* Some useful shortcuts. define MUI_NOSHORTCUTS to get rid of them */

#ifndef MUI_NOSHORTCUTS

#define _app(obj)         (muiGlobalInfo(obj).mgi_applicationobject)
#define _win(obj)         (muiRenderInfo(obj).mri_windowobject)
#define _dri(obj)         (muiRenderInfo(obj).mri_drawinfo)
#define _window(obj)      (muiRenderInfo(obj).mri_window)
#define _screen(obj)      (muiRenderInfo(obj).mri_screen)
#define _rp(obj)          (muiRenderInfo(obj).mri_rastport)
#define _left(obj)        (muiAreaData(obj).mad_box.left)
#define _top(obj)         (muiAreaData(obj).mad_box.top)
#define _width(obj)       (muiAreaData(obj).mad_box.width)
#define _height(obj)      (muiAreaData(obj).mad_box.height)
#define _right(obj)       (_left(obj)+_width(obj)-1)
#define _bottom(obj)      (_top(obj)+_height(obj)-1)
#define _addleft(obj)     (muiAreaData(obj).mad_addleft)
#define _addtop(obj)      (muiAreaData(obj).mad_addtop)
#define _subwidth(obj)    (muiAreaData(obj).mad_subwidth)
#define _subheight(obj)   (muiAreaData(obj).mad_subheight)
#define _mleft(obj)       (_left(obj)+_addleft(obj))
#define _mtop(obj)        (_top(obj)+_addtop(obj))
#define _mwidth(obj)      (_width(obj)-_subwidth(obj))
#define _mheight(obj)     (_height(obj)-_subheight(obj))
#define _mright(obj)      (_mleft(obj)+_mwidth(obj)-1)
#define _mbottom(obj)     (_mtop(obj)+_mheight(obj)-1)
#define _font(obj)        (muiAreaData(obj).mad_font)
#define _flags(obj)       (muiAreaData(obj).mad_flags)

#endif



/* MUI_CustomClass returned by MUI_CreateCustomClass() */

OBJECT mui_customclass
	mcc_userdata      : LONG
	mcc_utilitybase   : PTR TO lib
	mcc_dosbase       : PTR TO lib
	mcc_gfxbase       : PTR TO lib
	mcc_intuitionbase : PTR TO lib
	mcc_super         : PTR TO iclass
	mcc_class         : PTR TO iclass
ENDOBJECT
